@@ -6,7 +6,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
-/*			2003-2004 Alain Portal (dionysos@grisbi.org)	      */
+/*			2003-2004 Alain Portal (aportal@univ-montp2.fr)	      */
 /* 			http://www.grisbi.org				      */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -323,7 +323,7 @@ gboolean saisie_echeance_accueil ( GtkWidget *event_box,
     /* met le formulaire dans la boite de dialogue */
     width = frame_formulaire_echeancier -> allocation . width;
     if ( width <= 1 )
-        width = 700 ;
+        width = LOWEST_RESOLUTION ;
     gtk_widget_unrealize ( formulaire_echeancier );
     gtk_widget_reparent ( formulaire_echeancier, GTK_DIALOG ( dialog ) -> vbox );
     gtk_widget_set_usize ( GTK_WIDGET ( dialog ), width, FALSE );
