@@ -640,7 +640,7 @@ void remplit_arbre_categ ( void )
 	     nb_ecritures_par_categ[place_categ+1] )
 	    text[0] = g_strconcat ( categ -> nom_categ,
 				    " (",
-				    itoa ( nb_ecritures_par_categ[place_categ+1] ),
+				    utils_itoa ( nb_ecritures_par_categ[place_categ+1] ),
 				    ")",
 				    NULL );
 	else
@@ -693,7 +693,7 @@ void remplit_arbre_categ ( void )
 		 nb_ecritures_par_sous_categ[place_categ][place_sous_categ+1] )
 		text[0] = g_strconcat ( sous_categ -> nom_sous_categ,
 					" (",
-					itoa ( nb_ecritures_par_sous_categ[place_categ][place_sous_categ+1] ),
+					utils_itoa ( nb_ecritures_par_sous_categ[place_categ][place_sous_categ+1] ),
 					")",
 					NULL );
 	    else
@@ -1029,7 +1029,7 @@ gboolean ouverture_node_categ ( GtkWidget *arbre, GtkCTreeNode *node,
 			 nb_ecritures_par_comptes )
 			text[0] = g_strconcat ( NOM_DU_COMPTE,
 						" (",
-						itoa ( nb_ecritures_par_comptes ),
+						utils_itoa ( nb_ecritures_par_comptes ),
 						")",
 						NULL );
 		    else
@@ -1398,7 +1398,7 @@ void expand_selected_category ()
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte_courant;
 
-	if ( operation -> pointe == 2 && !AFFICHAGE_R )
+	if ( operation -> pointe == RECONCILED_TRANSACTION && !AFFICHAGE_R )
 	{
 	    AFFICHAGE_R = 1;
 	    remplissage_liste_operations ( compte_courant );
@@ -2072,7 +2072,7 @@ void supprimer_sous_categ ( void )
 	gint nouveau_no_categ;
 	gint nouveau_no_sous_categ;
 
-	dialog = gtk_dialog_new_with_buttons ( _("Remove category"),
+	dialog = gtk_dialog_new_with_buttons ( _("Remove sub-category"),
 					       GTK_WINDOW ( window ),
 					       GTK_DIALOG_MODAL,
 					       GTK_STOCK_OK, 0,
