@@ -164,6 +164,7 @@ static struct iso_4217_currency iso_4217_currencies[] = {
     { N_("Europe"), N_("Swedish Krona"), N_("Sweden"), "SEK", NULL, TRUE },
     { N_("Europe"), N_("Swiss Franc"), N_("Liechtenstein"), "CHF", NULL, TRUE },
     { N_("Europe"), N_("Swiss Franc"), N_("Switzerland"), "CHF", NULL, TRUE },
+    { N_("Europe"), N_("Hryvnia"), N_("Ukraine"), "UAH", NULL, TRUE },
     { N_("Northern America"), N_("Bahamian Dollar"), N_("Bahamas"), "BSD", NULL, TRUE },
     { N_("Northern America"), N_("Barbados Dollar"), N_("Barbados"), "BBD", NULL, TRUE },
     { N_("Northern America"), N_("Bermuda Dollar"), N_("Bermuda"), "BMD", NULL, TRUE },
@@ -200,6 +201,7 @@ static struct iso_4217_currency iso_4217_currencies[] = {
     { N_("Southern America"), N_("Ecuador Sucre"), N_("Ecuador"), "ECS", NULL, FALSE },
     { N_("Southern America"), N_("Guyana Dollar"), N_("Guyana"), "GYD", NULL, TRUE },
     { N_("Southern America"), N_("Paraguay Guarani"), N_("Paraguay"), "PYG", NULL, TRUE },
+    { N_("Southern America"), N_("Real"), N_("Brazil"), "BRL", "R$", TRUE },
     { N_("Southern America"), N_("Suriname Guilder"), N_("Suriname"), "SRG", NULL, TRUE },
     { N_("Southern America"), N_("Venezuelan Bolivar"), N_("Venezuela"), "VEB", NULL, TRUE },
     { NULL },
@@ -328,7 +330,6 @@ void update_currency_widgets()
 									   GINT_TO_POINTER ( DEVISE ),
 									   ( GCompareFunc ) recherche_devise_par_no )));
 
-
     /* on recrée les boutons de devises dans la conf de l'état */
 
     if ( onglet_config_etat )
@@ -504,9 +505,9 @@ void fill_currency_list ( GtkTreeView * view, gboolean include_obsolete )
 	gtk_tree_store_append (GTK_TREE_STORE(model), &iter, NULL);
 	gtk_tree_store_set (GTK_TREE_STORE(model), &iter,
 			    COUNTRY_NAME_COLUMN, _(*continent),
-			    CURRENCY_NAME_COLUMN, FALSE,
-			    CURRENCY_ISO_CODE_COLUMN, FALSE,
-			    CURRENCY_NICKNAME_COLUMN, FALSE,
+			    CURRENCY_NAME_COLUMN, NULL,
+			    CURRENCY_ISO_CODE_COLUMN, NULL,
+			    CURRENCY_NICKNAME_COLUMN, NULL,
 			    CONTINENT_NAME_COLUMN, _(*continent),
 			    -1);
 
@@ -1611,7 +1612,7 @@ GtkWidget *onglet_devises ( void )
 
 
 /**
- * Creates a new GtkOptionMenu with a pointer to an integerthat will
+ * Creates a new GtkOptionMenu with a pointer to an integer that will
  * be modified according to the entry's value.
  *
  * \param value A pointer to a string
@@ -1622,12 +1623,16 @@ GtkWidget *onglet_devises ( void )
 GtkWidget * new_currency_option_menu ( gint * value, GCallback hook )
 {
     GtkWidget * currency_list, *currency_menu;
+    gint gsb_currency_find_currency_in_option_menu ( GtkWidget *option_menu,
+						     gint no_currency );
 
     currency_list = gtk_option_menu_new ();
     currency_menu = creation_option_menu_devises ( 0, liste_struct_devises );
     gtk_option_menu_set_menu ( GTK_OPTION_MENU ( currency_list ), currency_menu );
     if (value && *value)
-	gtk_option_menu_set_history ( GTK_OPTION_MENU(currency_list), *value - 1 );
+	gtk_option_menu_set_history ( GTK_OPTION_MENU(currency_list),
+				      gsb_currency_find_currency_in_option_menu ( currency_list,
+										  *value ));
 
     g_signal_connect ( GTK_OBJECT (currency_list), "changed", (GCallback) set_int_from_menu, value );
     g_signal_connect ( GTK_OBJECT (currency_list), "changed", (GCallback) hook, value );
@@ -1636,6 +1641,32 @@ GtkWidget * new_currency_option_menu ( gint * value, GCallback hook )
     return currency_list;
 }
 
+/** look for a specific currency in an option menu and return its place in
+ * the menu, used to set the option menu on that currency with gtk_option_menu_set_history
+ * \param option_menu
+ * \param no_currency
+ * \return the place of the currency in the menu
+ * */
+gint gsb_currency_find_currency_in_option_menu ( GtkWidget *option_menu,
+						 gint no_currency )
+{
+    GList *children;
+    gint pos = 0;
+
+    children = GTK_MENU_SHELL ( gtk_option_menu_get_menu ( GTK_OPTION_MENU ( option_menu))) -> children;
+    
+    while ( children )
+    {
+	if ( GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( children -> data ),
+						   "no_devise" )) == no_currency )
+	    return pos;
+	pos++;
+
+	children = children -> next;
+    }
+
+    return 0;
+}
 
 
 /**
@@ -1644,7 +1675,7 @@ GtkWidget * new_currency_option_menu ( gint * value, GCallback hook )
  */
 GtkWidget *tab_display_totals ( void )
 {
-    GtkWidget *vbox_pref, *currency_list, *table, *label;
+    GtkWidget *vbox_pref, *currency_list, *table, *label, *label2, *label3;
 
     vbox_pref = new_vbox_with_title_and_icon ( _("Totals currencies"),
 					       "currencies.png" );
@@ -1663,20 +1694,20 @@ GtkWidget *tab_display_totals ( void )
     gtk_table_attach ( GTK_TABLE ( table ), currency_list,
 		       1, 2, 0, 1, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
-    label = gtk_label_new ( COLON ( _("Currency for categories tree") ) );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-    gtk_table_attach ( GTK_TABLE ( table ), label,
+    label2 = gtk_label_new ( COLON ( _("Currency for categories tree") ) );
+    gtk_misc_set_alignment (GTK_MISC (label2), 0, 1);
+    gtk_label_set_justify ( GTK_LABEL (label2), GTK_JUSTIFY_LEFT );
+    gtk_table_attach ( GTK_TABLE ( table ), label2,
 		       0, 1, 1, 2, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
     currency_list = new_currency_option_menu ( &no_devise_totaux_categ, 
 					       remplit_arbre_categ );
     gtk_table_attach ( GTK_TABLE ( table ), currency_list,
 		       1, 2, 1, 2, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
-    label = gtk_label_new ( COLON ( _("Currency for budgetary lines tree") ) );
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-    gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-    gtk_table_attach ( GTK_TABLE ( table ), label,
+    label3 = gtk_label_new ( COLON ( _("Currency for budgetary lines tree") ) );
+    gtk_misc_set_alignment (GTK_MISC (label3), 0, 1);
+    gtk_label_set_justify ( GTK_LABEL (label3), GTK_JUSTIFY_LEFT );
+    gtk_table_attach ( GTK_TABLE ( table ), label3,
 		       0, 1, 2, 3, GTK_SHRINK | GTK_FILL, 0, 0, 0 );
     currency_list = new_currency_option_menu ( &no_devise_totaux_ib, 
 					       remplit_arbre_imputation );
@@ -1685,6 +1716,11 @@ GtkWidget *tab_display_totals ( void )
 
     gtk_box_pack_start ( GTK_BOX ( vbox_pref ), table, TRUE, TRUE, 0);
 
+    gtk_widget_show_all ( vbox_pref );
+
+    if ( !nb_comptes )
+	gtk_widget_set_sensitive ( vbox_pref, FALSE );
+
     return ( vbox_pref );
 }
 
