@@ -1,11 +1,11 @@
 /* ************************************************************************** */
-/* Fichier qui s'occupe de la page d'accueil ( de démarrage lors de           */
-/* l'ouverture d'un fichier de comptes                                        */
+/* Différentes boites de dialogue pour informer et interroger l'utilisateur   */
 /*                                                                            */
-/*                                  accueil.c                                 */
+/*                                  dialog.c                                  */
 /*                                                                            */
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
+/*			2005 Alain Portal (aportal@univ-montp2.fr) 	      */
 /* 			http://www.grisbi.org				      */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -313,6 +313,71 @@ gboolean question_yes_no ( gchar *texte )
 }
 
 
+/**
+ * This function pop ups a dialog with a hint (first sentence, in bold),
+ * a question, a checkbox that allow this message not to be displayed again
+ * thanks to preferences and wait for user to press 'OK' or 'Cancel'..
+ * It calls question_conditional_yes_no to achieve display.
+ *
+ * \param text text to be displayed
+ * \param hint hint to be displayed
+ * \param var variable that both controls whether the dialog will
+ * appear or not and that indicates which variable could be modified
+ * so that this message won't appear again.
+ */
+gboolean question_conditional_yes_no_hint ( gchar *hint, gchar * text, int * var )
+{
+    return question_conditional_yes_no ( make_hint(hint, text), var );
+}
+
+
+/**
+ * Pop up a warning dialog window with a question and a checkbox that allow
+ * this message not to be displayed again thanks to preferences and wait
+ * for user to press 'OK' or 'Cancel'.
+ *
+ * \param texte  Text to be displayed
+ * \param var variable that both controls whether the dialog will
+ * appear or not and that indicates which variable could be modified
+ * so that this message won't appear again.
+ *
+ * \return TRUE if user pressed 'OK'.  FALSE otherwise.
+ */
+gboolean question_conditional_yes_no ( gchar *texte, int * var )
+{
+    GtkWidget * vbox, * checkbox, *dialog;
+    gint response;
+
+    if ( !var || *var)
+	return TRUE;
+
+    dialog = gtk_message_dialog_new ( GTK_WINDOW ( window ),
+				      GTK_DIALOG_DESTROY_WITH_PARENT,
+				      GTK_MESSAGE_WARNING,
+				      GTK_BUTTONS_OK_CANCEL,
+				      texte );
+    gtk_dialog_set_default_response ( GTK_DIALOG ( dialog ),
+				      GTK_RESPONSE_CANCEL );
+    gtk_label_set_markup ( GTK_LABEL ( GTK_MESSAGE_DIALOG ( dialog ) -> label ), texte );
+
+    vbox = GTK_DIALOG ( dialog ) -> vbox;
+    checkbox = new_checkbox_with_title ( _("Do not show this message again"), var, 
+					 NULL );
+    gtk_box_pack_start ( GTK_BOX ( vbox ), checkbox, TRUE, TRUE, 6 );
+    gtk_widget_show_all ( checkbox );
+
+    gtk_window_set_modal ( GTK_WINDOW ( dialog ), TRUE );
+
+    response = gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy ( dialog );
+
+    if ( response == GTK_RESPONSE_OK )
+	return TRUE;
+    else
+	return FALSE;
+}
+
+
 
 
 /*************************************************************************************************************/
