@@ -3,7 +3,7 @@
 /* 			echeances_liste.c                                     */
 /*                                                                            */
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
-/*			2004 Alain Portal (dionysos@grisbi.org) 	      */
+/*			2004-2005 Alain Portal (aportal@univ-montp2.fr)	      */
 /*			2004 Benjamin Drieu (bdrieu@april.org)  	      */
 /* 			http://www.grisbi.org   			      */
 /*                                                                            */
@@ -72,8 +72,8 @@ GtkWidget *formulaire_echeancier;
 GtkWidget *liste_echeances;
 GtkWidget *entree_personnalisation_affichage_echeances;
 GtkWidget *bouton_personnalisation_affichage_echeances;
-GtkWidget *bouton_valider_echeance_perso;
 GtkWidget *bouton_saisir_echeancier;
+GtkWidget *bouton_supprimer_echeancier;
 GtkWidget *calendrier_echeances;
 
 struct operation_echeance *echeance_selectionnnee;
@@ -99,6 +99,7 @@ extern GtkWidget *widget_formulaire_echeancier[SCHEDULER_FORM_TOTAL_WIDGET];
 GtkWidget *creation_partie_gauche_echeancier ( void )
 {
     GtkWidget *vbox;
+    GtkWidget *vbox2;
     GtkWidget *separation;
     GtkWidget *hbox;
     GtkWidget *label;
@@ -254,18 +255,6 @@ GtkWidget *creation_partie_gauche_echeancier ( void )
 			 0 );
     gtk_widget_show ( hbox );
 
-    /* met un bouton valider qui est juste utilisé pour faire sortir le focus de l'entrée */
-    /* Pas de handler associé car il suffit juste de faire perdre le focus */
-    bouton_valider_echeance_perso = gtk_button_new_with_label ( _("Show"));
-    gtk_button_set_relief ( GTK_BUTTON ( bouton_valider_echeance_perso ),
-			    GTK_RELIEF_NONE );
-    gtk_box_pack_end ( GTK_BOX ( hbox ),
-		       bouton_valider_echeance_perso,
-		       FALSE,
-		       FALSE,
-		       0 );
-
-
     /* le menu jour / mois / année */
 
     bouton_personnalisation_affichage_echeances = gtk_option_menu_new ();
@@ -338,26 +327,25 @@ GtkWidget *creation_partie_gauche_echeancier ( void )
     {
 	if ( affichage_echeances_perso_nb_libre )
 	    gtk_entry_set_text ( GTK_ENTRY ( entree_personnalisation_affichage_echeances ),
-				 itoa ( affichage_echeances_perso_nb_libre ));
+				 utils_itoa ( affichage_echeances_perso_nb_libre ));
 	gtk_option_menu_set_history ( GTK_OPTION_MENU ( bouton_personnalisation_affichage_echeances ),
 				      affichage_echeances_perso_j_m_a );
 	gtk_widget_show ( entree_personnalisation_affichage_echeances );
 	gtk_widget_show ( bouton_personnalisation_affichage_echeances );
-	gtk_widget_show ( bouton_valider_echeance_perso );
     }
 
 
 
     /* place en dessous les boutons Saisir */
 
-    hbox = gtk_hbox_new ( TRUE,
+    vbox2 = gtk_vbox_new ( TRUE,
 			  10 );
     gtk_box_pack_end ( GTK_BOX ( vbox ),
-		       hbox,
+		       vbox2,
 		       FALSE,
 		       FALSE,
 		       5 );
-    gtk_widget_show ( hbox );
+    gtk_widget_show ( vbox2 );
 
     separation = gtk_hseparator_new ();
     gtk_box_pack_end ( GTK_BOX ( vbox ),
@@ -367,12 +355,12 @@ GtkWidget *creation_partie_gauche_echeancier ( void )
 		       5 );
     gtk_widget_show ( separation );
 
-    bouton_saisir_echeancier = gtk_button_new_with_label ( _("Remove selected\nscheduled transaction") );
+    bouton_saisir_echeancier = gtk_button_new_with_label ( _("Fall due selected\nscheduled transaction") );
     gtk_button_set_relief ( GTK_BUTTON ( bouton_saisir_echeancier ), GTK_RELIEF_NONE );
     gtk_signal_connect_object ( GTK_OBJECT ( bouton_saisir_echeancier ), "clicked",
-				GTK_SIGNAL_FUNC ( supprime_echeance), NULL );
+				GTK_SIGNAL_FUNC ( click_sur_saisir_echeance ), NULL );
 
-    gtk_box_pack_start ( GTK_BOX ( hbox ),
+    gtk_box_pack_start ( GTK_BOX ( vbox2 ),
 			 bouton_saisir_echeancier,
 			 TRUE,
 			 FALSE,
@@ -381,6 +369,20 @@ GtkWidget *creation_partie_gauche_echeancier ( void )
 			       FALSE );
     gtk_widget_show ( bouton_saisir_echeancier );
 
+    bouton_supprimer_echeancier = gtk_button_new_with_label ( _("Remove selected\nscheduled transaction") );
+    gtk_button_set_relief ( GTK_BUTTON ( bouton_supprimer_echeancier ), GTK_RELIEF_NONE );
+    gtk_signal_connect_object ( GTK_OBJECT ( bouton_supprimer_echeancier ), "clicked",
+				GTK_SIGNAL_FUNC ( supprime_echeance), NULL );
+
+    gtk_box_pack_start ( GTK_BOX ( vbox2 ),
+			 bouton_supprimer_echeancier,
+			 TRUE,
+			 FALSE,
+			 0 );
+    gtk_widget_set_sensitive ( GTK_WIDGET ( bouton_supprimer_echeancier ),
+			       FALSE );
+    gtk_widget_show ( bouton_supprimer_echeancier );
+
     return ( vbox );
 }
 /*****************************************************************************/
@@ -604,7 +606,11 @@ gboolean traitement_clavier_liste_echeances ( GtkCList *liste_echeances,
 
 	case GDK_Delete :               /*  del  */
 
-	    supprime_echeance ( echeance_selectionnnee );
+	    if ( question_conditional_yes_no_hint ( _("Confirmation of scheduled transaction removal"),
+						    _("You are currently trying to remove a scheduled transaction.  There "
+						      "is no undo for this.  Do you confirm the removal?"),
+						    &etat.display_message_remove_scheduled_transaction))
+		supprime_echeance ( echeance_selectionnnee );
 	    //      return TRUE; c'est le cas de la 0.4.4, et pas de break
 	    break;
 
@@ -1021,12 +1027,19 @@ void selectionne_echeance ( void )
     }
 
     if ( echeance_selectionnnee != GINT_TO_POINTER ( -1 ) )
+    {
 	gtk_widget_set_sensitive ( GTK_WIDGET ( bouton_saisir_echeancier ),
 				   TRUE );
+	gtk_widget_set_sensitive ( GTK_WIDGET ( bouton_supprimer_echeancier ),
+				   TRUE );
+    }
     else
+    {
 	gtk_widget_set_sensitive ( GTK_WIDGET ( bouton_saisir_echeancier ),
 				   FALSE );
-
+	gtk_widget_set_sensitive ( GTK_WIDGET ( bouton_supprimer_echeancier ),
+				   FALSE );
+    }
 }
 /*****************************************************************************/
 
@@ -1315,7 +1328,7 @@ void edition_echeance ( void )
     {
 	entree_prend_focus ( widget_formulaire_echeancier[SCHEDULER_FORM_FREQ_CUSTOM_NB] );
 	gtk_entry_set_text ( GTK_ENTRY (widget_formulaire_echeancier[SCHEDULER_FORM_FREQ_CUSTOM_NB] ),
-			     itoa ( echeance_selectionnnee ->  periodicite_personnalisee) );
+			     utils_itoa ( echeance_selectionnnee ->  periodicite_personnalisee) );
 	gtk_option_menu_set_history ( GTK_OPTION_MENU ( widget_formulaire_echeancier[SCHEDULER_FORM_FREQ_CUSTOM_MENU] ),
 				      echeance_selectionnnee -> intervalle_periodicite_personnalisee );
 	gtk_widget_show ( widget_formulaire_echeancier[SCHEDULER_FORM_FREQ_CUSTOM_NB] );
@@ -1506,9 +1519,9 @@ void changement_taille_liste_echeances ( GtkWidget *clist,
     gint i;
     gint col1, col2, col3, col4, col5, col6, col7;
 
-    /*   si la largeur de grisbi est < 700, on fait rien */
+    /*   si la largeur de grisbi est < LOWEST_RESOLUTION, on fait rien */
 
-    if ( window -> allocation.width < 700 )
+    if ( window -> allocation.width < LOWEST_RESOLUTION )
 	return;
 
     /* si ancienne_largeur est nul, c'est que la vue sur la liste n'a pas encore
@@ -2181,12 +2194,11 @@ gboolean modification_affichage_echeances ( gint *origine, GtkWidget * widget )
 	    affichage_echeances = GPOINTER_TO_INT ( origine );
 	    if ( affichage_echeances_perso_nb_libre )
 		gtk_entry_set_text ( GTK_ENTRY ( entree_personnalisation_affichage_echeances ),
-				     itoa ( affichage_echeances_perso_nb_libre ));
+				     utils_itoa ( affichage_echeances_perso_nb_libre ));
 	    gtk_option_menu_set_history ( GTK_OPTION_MENU ( bouton_personnalisation_affichage_echeances ),
 					  affichage_echeances_perso_j_m_a );
 	    gtk_widget_show ( entree_personnalisation_affichage_echeances );
 	    gtk_widget_show ( bouton_personnalisation_affichage_echeances );
-	    gtk_widget_show ( bouton_valider_echeance_perso );
 	    break;
 
 	case 0:
@@ -2196,7 +2208,6 @@ gboolean modification_affichage_echeances ( gint *origine, GtkWidget * widget )
 	    affichage_echeances = GPOINTER_TO_INT ( origine );
 	    gtk_widget_hide ( entree_personnalisation_affichage_echeances );
 	    gtk_widget_hide ( bouton_personnalisation_affichage_echeances );
-	    gtk_widget_hide ( bouton_valider_echeance_perso );
 
 	    break;
 
