@@ -807,7 +807,7 @@ gboolean entree_ventilation_perd_focus_echeances ( GtkWidget *entree, GdkEventFo
 				if ( !GTK_WIDGET_VISIBLE ( widget_formulaire_ventilation_echeances[SCHEDULER_BREAKDOWN_FORM_CONTRA] )
 				     ||
 				     ( GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT ( GTK_OPTION_MENU ( widget_formulaire_ventilation_echeances[SCHEDULER_BREAKDOWN_FORM_CONTRA] ) -> menu ),
-									       "no_compte" ))
+									       "compte_virement" ))
 				       !=
 				       compte_virement ))
 				{
@@ -1119,9 +1119,9 @@ void changement_taille_liste_ventilation_echeances  ( GtkWidget *clist,
     gint largeur;
     gint col0, col1, col2;
 
-    /*   si la largeur de grisbi est < 700, on fait rien */
+    /*   si la largeur de grisbi est < LOWEST_RESOLUTION, on fait rien */
 
-    if ( window -> allocation.width < 700 )
+    if ( window -> allocation.width < LOWEST_RESOLUTION )
 	return;
 
     largeur = allocation->width;
@@ -1616,7 +1616,6 @@ void fin_edition_ventilation_echeances ( void )
 		    return;
 		}
 	    }
-	    g_strfreev ( tableau_char );
 	}
     }
 
@@ -1655,6 +1654,10 @@ void fin_edition_ventilation_echeances ( void )
     {
 	struct struct_categ *categ;
 
+       tableau_char = g_strsplit ( g_strstrip ( gtk_combofix_get_text ( GTK_COMBOFIX ( widget_formulaire_ventilation_echeances[SCHEDULER_BREAKDOWN_FORM_CATEGORY] ))),
+                                   ":",
+                                   2 );
+
 	if ( strlen ( tableau_char[0] ) )
 	{
 	    /* on vérifie ici si c'est un virement */
@@ -1764,19 +1767,9 @@ void fin_edition_ventilation_echeances ( void )
     }
     else
     {
-	/* il n'y a aucune catég, si c'est une modif d'opé et que cette opé était un virement, */
-	/* on marque cette opé comme supprimée et on en recrée une nouvelle */
-
-	if ( modification
-	     &&
-	     operation -> relation_no_operation )
-	{
-	    operation -> supprime = 1;
-	    operation = calloc ( 1,
-				 sizeof ( struct struct_ope_ventil ));
-	    modification = 0;
-	    perte_ligne_selectionnee = 1;
-	}
+	operation -> categorie = 0;
+	operation -> sous_categorie = 0;
+	operation -> relation_no_compte = -1;
     }
 
     /* récupération du type d'opé associée s'il est affiché */
@@ -2758,7 +2751,6 @@ void validation_ope_de_ventilation_echeances ( struct operation_echeance *operat
 
 		/* on récupère d'abord les modifs de l'opé de ventil */
 
-		ope_ventil -> relation_no_operation = -1;
 		nouvelle_ope -> montant = ope_ventil -> montant;
 		nouvelle_ope -> categorie = ope_ventil -> categorie;
 		nouvelle_ope -> sous_categorie = ope_ventil -> sous_categorie;
