@@ -4,7 +4,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003 Benjamin Drieu (bdrieu@april.org)		      */
-/*			2004 Alain Portal (dionysos@grisbi.org) 	      */
+/*			2004 Alain Portal (aportal@univ-montp2.fr) 	      */
 /*			http://www.grisbi.org   			      */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -504,7 +504,7 @@ void equilibrage ( void )
 
 		/* on incrémente la partie numérique */
 
-		partie_num = itoa ( my_atoi ( partie_num ) + 1 );
+		partie_num = utils_itoa ( my_atoi ( partie_num ) + 1 );
 
 		/* si la nouvelle partie numérique est plus petite que l'ancienne, */
 		/* c'est que des 0 ont été shuntés, on va les rajouter ici */
@@ -618,8 +618,11 @@ void equilibrage ( void )
 
     etat.valeur_r_avant_rapprochement = AFFICHAGE_R;
 
-    change_aspect_liste ( NULL,
-			  3 );
+    AFFICHAGE_R = 0;
+    MISE_A_JOUR = 1;
+    focus_a_la_liste ();
+/*     change_aspect_liste ( NULL, */
+/* 			  3 ); */
 
 
     /* classe la liste des opés en fonction des types ou non */
@@ -751,8 +754,13 @@ gboolean annuler_equilibrage ( GtkWidget *bouton_ann,
 
 
     if ( etat.valeur_r_avant_rapprochement )
-	change_aspect_liste ( NULL,
-			      2 );
+    {
+	AFFICHAGE_R = 1;
+	MISE_A_JOUR = 1;
+	focus_a_la_liste ();
+/* 	change_aspect_liste ( NULL, */
+/* 			      2 ); */
+    }
 
     LISTE_OPERATIONS = g_slist_sort ( LISTE_OPERATIONS,
 				      (GCompareFunc) classement_sliste );
@@ -800,7 +808,7 @@ void pointe_equilibrage ( int p_ligne )
 	return;
 
 
-    if ( operation -> pointe == 2 )
+    if ( operation -> pointe == RECONCILED_TRANSACTION )
 	return;
 
 
@@ -819,7 +827,7 @@ void pointe_equilibrage ( int p_ligne )
 	operations_pointees = operations_pointees - montant;
 	SOLDE_POINTE = SOLDE_POINTE - montant;
 
-	operation -> pointe = 0;
+	operation -> pointe = UNCHECKED_TRANSACTION;
 
 	gtk_clist_set_text ( GTK_CLIST ( CLIST_OPERATIONS ),
 			     p_ligne,
@@ -831,7 +839,7 @@ void pointe_equilibrage ( int p_ligne )
 	operations_pointees = operations_pointees + montant;
 	SOLDE_POINTE = SOLDE_POINTE + montant;
 
-	operation -> pointe = 1;
+	operation -> pointe = CHECKED_TRANSACTION;
 
 	gtk_clist_set_text ( GTK_CLIST ( CLIST_OPERATIONS ),
 			     p_ligne,
@@ -990,6 +998,13 @@ gboolean fin_equilibrage ( GtkWidget *bouton_ok,
 	if ( liste_tmp )
 	{
 	    /* le rapprochement existe déjà */
+	    if ( !question_conditional_yes_no_hint ( _("Reconciliation reference already exist"),
+						     _("The choosen reconciliation reference already "
+						       "exists.  Perhaps it's not a problem, but perhaps "
+						       "it is.  Be sure you want to do.\nProceed anyway?"),
+						     &etat.display_message_reconciliation_ref_exist)) {
+	        return FALSE;
+	    }
 
 	    rapprochement = liste_tmp -> data;
 	    DERNIER_NO_RAPPROCHEMENT = rapprochement -> no_rapprochement;
@@ -1009,8 +1024,27 @@ gboolean fin_equilibrage ( GtkWidget *bouton_ok,
 	}
     }
     else
+    {
+	if ( !question_conditional_yes_no_hint ( _("No reconciliation reference"),
+						 _("You are reconciling the account without giving a "
+						   "reconciliation reference.  By doing this, you will "
+						   "unable to find these transactions according a "
+						   "reconciliation reference.\nProceed anyway?"),
+						 &etat.display_message_no_reconciliation_ref)) {
+	    return FALSE;
+	}
 	DERNIER_NO_RAPPROCHEMENT = 0;
+    }
 
+    /* FIXME : hide that now, to remove later if nobody ask for  it */
+
+/*     if ( !question_conditional_yes_no_hint ( _("Last chance to abort reconciliation!"), */
+/* 					     _("You are reconciling the account.  Pass this step, " */
+/* 					       "you won't able to undo unless not save the file and " */
+/* 					       "reload it.  Be sure you want to do.\nProceed anyway?"), */
+/* 					     &etat.display_message_aborting_reconciliation)) { */
+/* 	return FALSE; */
+/*     } */
 
 
     /* met tous les P à R */
@@ -1025,9 +1059,10 @@ gboolean fin_equilibrage ( GtkWidget *bouton_ok,
 
 	operation = pointeur_liste_ope -> data;
 
-	if ( operation -> pointe == 1 )
+	if ( operation -> pointe == CHECKED_TRANSACTION ||
+	     operation -> pointe == TELECHECKED_TRANSACTION )
 	{
-	    operation -> pointe = 2;
+	    operation -> pointe = RECONCILED_TRANSACTION;
 	    operation -> no_rapprochement = DERNIER_NO_RAPPROCHEMENT;
 	}
 
@@ -1062,8 +1097,13 @@ gboolean fin_equilibrage ( GtkWidget *bouton_ok,
     }
 
     if ( etat.valeur_r_avant_rapprochement )
-	change_aspect_liste ( NULL,
-			      2 );
+    {
+	AFFICHAGE_R = 1;
+	MISE_A_JOUR = 1;
+	focus_a_la_liste ();
+/* 	change_aspect_liste ( NULL, */
+/* 			      2 ); */
+    }
 
     LISTE_OPERATIONS = g_slist_sort ( LISTE_OPERATIONS,
 				      (GCompareFunc) classement_sliste );
@@ -1106,8 +1146,8 @@ void calcule_total_pointe_compte ( gint no_compte )
 
 	/* on ne prend en compte l'opé que si c'est pas une opé de ventil */
 
-	if ( operation -> pointe == 1
-	     &&
+	if ( ( operation -> pointe == CHECKED_TRANSACTION ||
+	       operation -> pointe == TELECHECKED_TRANSACTION ) &&
 	     !operation -> no_operation_ventilee_associee )
 	{
 	    gdouble montant;
@@ -1227,14 +1267,17 @@ void fill_reconciliation_tree ()
     GtkTreeIter account_iter, payment_method_iter;
     GSList *pUserAccountsList = NULL;
 
+    if ( nb_comptes == 0 )
+	return;
+
     pUserAccountsList = g_slist_copy ( ordre_comptes );
 
     do
     {
-	p_tab_nom_de_compte_variable = p_tab_nom_de_compte + GPOINTER_TO_INT ( pUserAccountsList -> data );
-
 	GSList * liste_tmp;
 
+	p_tab_nom_de_compte_variable = p_tab_nom_de_compte + GPOINTER_TO_INT ( pUserAccountsList -> data );
+
 	gtk_tree_store_append (reconcile_model, &account_iter, NULL);
 	gtk_tree_store_set (reconcile_model, &account_iter,
 			    RECONCILIATION_NAME_COLUMN, NOM_DU_COMPTE,
