@@ -417,13 +417,16 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 
 		if ( etat -> afficher_r )
 		{
-		    if ( ( etat -> afficher_r == 1
-			   &&
-			   operation -> pointe == 2 )
-			 ||
-			 ( etat -> afficher_r == 2
-			   &&
-			   operation -> pointe != 2 ))
+		    if ( ( etat -> afficher_r == 1 &&
+			   operation -> pointe == RECONCILED_TRANSACTION ) ||
+			 ( etat -> afficher_r == 2 &&
+			   operation -> pointe != RECONCILED_TRANSACTION ) ||
+			 ( etat -> afficher_r == 3 &&
+			   ( operation -> pointe == RECONCILED_TRANSACTION || operation -> pointe == UNCHECKED_TRANSACTION )) ||
+			 ( etat -> afficher_r == 4 &&
+			   operation -> pointe != UNCHECKED_TRANSACTION ))
+
+
 			goto operation_refusee;
 		}
 
@@ -1135,7 +1138,7 @@ gint verifie_texte_test_etat ( struct struct_comparaison_textes_etat *comp_texte
 	case 4:
 	    /* vide  */
 
-	    if ( !texte_ope )
+	    if ( !texte_ope || !strlen(texte_ope) )
 		ope_dans_test = 1;
 	    break;
 
@@ -2189,6 +2192,7 @@ pas_decalage:
 	nb_colonnes = nb_colonnes + etat_courant -> afficher_type_ope;
 	nb_colonnes = nb_colonnes + etat_courant -> afficher_cheque_ope;
 	nb_colonnes = nb_colonnes + etat_courant -> afficher_rappr_ope;
+	nb_colonnes = nb_colonnes + etat_courant -> afficher_verif_ope;
 	nb_colonnes = nb_colonnes + etat_courant -> afficher_exo_ope;
 
 	/* on ajoute les séparations */
