@@ -40,6 +40,7 @@
 GtkWidget *paddingbox_details;	/** Widget handling financial year details */
 
 extern GtkWidget *widget_formulaire_echeancier[SCHEDULER_FORM_TOTAL_WIDGET];
+extern GtkWidget *widget_formulaire_ventilation_echeances[SCHEDULER_BREAKDOWN_FORM_TOTAL_WIDGET];
 
 
 /** 
@@ -79,28 +80,33 @@ gboolean update_financial_year_menus ()
     if ( widget_formulaire_operations[TRANSACTION_FORM_EXERCICE] &&
 	 GTK_OPTION_MENU(widget_formulaire_operations[TRANSACTION_FORM_EXERCICE]) -> menu )
     {
-      if ( GTK_OPTION_MENU(widget_formulaire_operations[TRANSACTION_FORM_EXERCICE]) -> menu )
 	gtk_widget_destroy ( GTK_OPTION_MENU(widget_formulaire_operations[TRANSACTION_FORM_EXERCICE]) -> menu );
-      gtk_option_menu_set_menu ( GTK_OPTION_MENU (widget_formulaire_operations[TRANSACTION_FORM_EXERCICE]),
-				 creation_menu_exercices (0) );
+	gtk_option_menu_set_menu ( GTK_OPTION_MENU (widget_formulaire_operations[TRANSACTION_FORM_EXERCICE]),
+				   creation_menu_exercices (0) );
     }
 
-    if ( widget_formulaire_operations[TRANSACTION_FORM_DEVISE] &&
-	 GTK_OPTION_MENU(widget_formulaire_operations[TRANSACTION_FORM_DEVISE]) -> menu )
+    if ( widget_formulaire_ventilation[TRANSACTION_BREAKDOWN_FORM_EXERCICE] &&
+	 GTK_OPTION_MENU(widget_formulaire_ventilation[TRANSACTION_BREAKDOWN_FORM_EXERCICE]) -> menu )
     {
-      if ( GTK_OPTION_MENU(widget_formulaire_ventilation[TRANSACTION_BREAKDOWN_FORM_CONTRA]) -> menu )
-	gtk_widget_destroy ( GTK_OPTION_MENU(widget_formulaire_ventilation[TRANSACTION_BREAKDOWN_FORM_CONTRA]) -> menu );
-      gtk_option_menu_set_menu ( GTK_OPTION_MENU(widget_formulaire_ventilation[TRANSACTION_BREAKDOWN_FORM_CONTRA]),
-				 creation_menu_exercices (0) );
+	gtk_widget_destroy ( GTK_OPTION_MENU(widget_formulaire_ventilation[TRANSACTION_BREAKDOWN_FORM_EXERCICE]) -> menu );
+	gtk_option_menu_set_menu ( GTK_OPTION_MENU (widget_formulaire_ventilation[TRANSACTION_BREAKDOWN_FORM_EXERCICE]),
+				   creation_menu_exercices (0) );
     }
 
-    if ( widget_formulaire_operations[TRANSACTION_FORM_TYPE] &&
-	 GTK_OPTION_MENU(widget_formulaire_operations[TRANSACTION_FORM_TYPE]) -> menu )
+    if ( widget_formulaire_echeancier[SCHEDULER_FORM_EXERCICE] &&
+	 GTK_OPTION_MENU(widget_formulaire_echeancier[SCHEDULER_FORM_EXERCICE]) -> menu )
     {
-      if ( GTK_OPTION_MENU(widget_formulaire_echeancier[SCHEDULER_FORM_EXERCICE]) -> menu )
 	gtk_widget_destroy ( GTK_OPTION_MENU(widget_formulaire_echeancier[SCHEDULER_FORM_EXERCICE]) -> menu );
-      gtk_option_menu_set_menu ( GTK_OPTION_MENU(widget_formulaire_echeancier[SCHEDULER_FORM_EXERCICE]),
-				 creation_menu_exercices (1) );
+	gtk_option_menu_set_menu ( GTK_OPTION_MENU (widget_formulaire_echeancier[SCHEDULER_FORM_EXERCICE]),
+				   creation_menu_exercices (1) );
+    }
+
+    if ( widget_formulaire_ventilation_echeances[SCHEDULER_BREAKDOWN_FORM_EXERCICE] &&
+	 GTK_OPTION_MENU(widget_formulaire_ventilation_echeances[SCHEDULER_BREAKDOWN_FORM_EXERCICE]) -> menu )
+    {
+	gtk_widget_destroy ( GTK_OPTION_MENU(widget_formulaire_ventilation_echeances[SCHEDULER_BREAKDOWN_FORM_EXERCICE]) -> menu );
+	gtk_option_menu_set_menu ( GTK_OPTION_MENU (widget_formulaire_ventilation_echeances[SCHEDULER_BREAKDOWN_FORM_EXERCICE]),
+				   creation_menu_exercices (1) );
     }
 
     return FALSE;
@@ -201,7 +207,7 @@ GtkWidget *onglet_exercices ( void )
     gtk_box_pack_start ( GTK_BOX ( vbox ), bouton_supprimer_exercice,
 			 FALSE, FALSE, 5 );
     /* Associate operations */
-    bouton = gtk_button_new_with_label ( _("Associate operations without financial years") );
+    bouton = gtk_button_new_with_label ( _("Associate transactions without financial years") );
     gtk_signal_connect ( GTK_OBJECT ( bouton ),
 			 "clicked",
 			 GTK_SIGNAL_FUNC ( association_automatique ),
