@@ -4,7 +4,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2004 Benjamin Drieu (bdrieu@april.org)		      */
-/*			2004 Alain Portal (dionysos@grisbi.org) 	      */
+/*			2004 Alain Portal (aportal@univ-montp2.fr) 	      */
 /*			http://www.grisbi.org   			      */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -554,7 +554,7 @@ void remplit_arbre_imputation ( void )
 	     nb_ecritures_par_imputation[place_imputation+1] )
 	    text[0] = g_strconcat ( imputation -> nom_imputation,
 				    " (",
-				    itoa ( nb_ecritures_par_imputation[place_imputation+1] ),
+				    utils_itoa ( nb_ecritures_par_imputation[place_imputation+1] ),
 				    ")",
 				    NULL );
 	else
@@ -610,7 +610,7 @@ void remplit_arbre_imputation ( void )
 		 nb_ecritures_par_sous_imputation[place_imputation][place_sous_imputation+1] )
 		text[0] = g_strconcat ( sous_imputation -> nom_sous_imputation,
 					" (",
-					itoa ( nb_ecritures_par_sous_imputation[place_imputation][place_sous_imputation+1] ),
+					utils_itoa ( nb_ecritures_par_sous_imputation[place_imputation][place_sous_imputation+1] ),
 					")",
 					NULL );
 	    else
@@ -945,7 +945,7 @@ void ouverture_node_imputation ( GtkWidget *arbre,
 			 nb_ecritures_par_comptes )
 			text[0] = g_strconcat ( NOM_DU_COMPTE,
 						" (",
-						itoa ( nb_ecritures_par_comptes ),
+						utils_itoa ( nb_ecritures_par_comptes ),
 						")",
 						NULL );
 		    else
@@ -1306,7 +1306,7 @@ gboolean expand_selected_ib (  )
 
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte_courant;
 
-	if ( operation -> pointe == 2 && !AFFICHAGE_R )
+	if ( operation -> pointe == RECONCILED_TRANSACTION && !AFFICHAGE_R )
 	{
 	    AFFICHAGE_R = 1;
 	    remplissage_liste_operations ( compte_courant );
