@@ -1,22 +1,26 @@
-/* permet la configuration du logiciel */
-
-/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org) */
-/*			2003-2004 Benjamin Drieu (bdrieu@april.org) */
-/* 			http://www.grisbi.org */
-
-/*     This program is free software; you can redistribute it and/or modify */
-/*     it under the terms of the GNU General Public License as published by */
-/*     the Free Software Foundation; either version 2 of the License, or */
-/*     (at your option) any later version. */
-
-/*     This program is distributed in the hope that it will be useful, */
-/*     but WITHOUT ANY WARRANTY; without even the implied warranty of */
-/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
-/*     GNU General Public License for more details. */
-
-/*     You should have received a copy of the GNU General Public License */
-/*     along with this program; if not, write to the Free Software */
-/*     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* ************************************************************************** */
+/* Ce fichier se charge de la configuration du logiciel                       */
+/*                                                                            */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
+/*			2003-2004 Benjamin Drieu (bdrieu@april.org) 	      */
+/*			2005      Alain Portal (aportal@univ-montp2.fr)	      */
+/*			http://www.grisbi.org   			      */
+/*                                                                            */
+/*  This program is free software; you can redistribute it and/or modify      */
+/*  it under the terms of the GNU General Public License as published by      */
+/*  the Free Software Foundation; either version 2 of the License, or         */
+/*  (at your option) any later version.                                       */
+/*                                                                            */
+/*  This program is distributed in the hope that it will be useful,           */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of            */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
+/*  GNU General Public License for more details.                              */
+/*                                                                            */
+/*  You should have received a copy of the GNU General Public License         */
+/*  along with this program; if not, write to the Free Software               */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/*                                                                            */
+/* ************************************************************************** */
 
 #include "include.h"
 #include "structures.h"
@@ -45,7 +49,6 @@ gint preference_selected = -1;
 GtkTreeSelection * selection;
 GtkWidget * button_close, * button_help;
 GtkWidget *tree_view;
-GtkWidget * bouton_display_lock_active;
 
 extern gint decalage_echeance; 
 
@@ -372,6 +375,7 @@ GtkWidget *onglet_messages_and_warnings ( void )
 {
     GtkWidget *hbox, *vbox_pref;
     GtkWidget *paddingbox, *label;
+    GtkWidget *pCheckBox;
 
     vbox_pref = new_vbox_with_title_and_icon ( _("Messages & warnings"),
 					       "warnings.png" );
@@ -381,28 +385,64 @@ GtkWidget *onglet_messages_and_warnings ( void )
 					    _("Warnings messages"));
 
     /* Display a warning message if minimum balances are under minimum level */
-    bouton_solde_mini = new_checkbox_with_title ( _("Do not Warn if balances are under minimum levels"),
-						  &(etat.display_message_minimum_alert), NULL );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), bouton_solde_mini, FALSE, FALSE, 0 );
+    pCheckBox = new_checkbox_with_title ( _("Do not Warn if balances are under minimum levels"),
+					  &(etat.display_message_minimum_alert), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
 
     /* Display a warning message if account file is readable by someone else */
     /* On Windows, the chmod feature does not work: FAT does not have right access permission notions , 
      * on NTFS it to complicated to implement => the feature is removed from the Windows version :
      * for that the corresponding parameter check box is not displayed and the paramater is forced to not display msg ( 1!!! ) */
 #ifndef _WIN32
-    bouton_affiche_permission = new_checkbox_with_title ( _("Do not warn if account file is readable by someone else"),
-							  &(etat.display_message_file_readable), NULL );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), bouton_affiche_permission, FALSE, FALSE, 0 );
+    pCheckBox = new_checkbox_with_title ( _("Do not warn if account file is readable by someone else"),
+					  &(etat.display_message_file_readable), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
 #endif
     /* Display a warning message if file is already opened */
-    bouton_display_lock_active = new_checkbox_with_title ( _("Do not warn about an already opened file"),
-							   &(etat.display_message_lock_active), NULL );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), bouton_display_lock_active, FALSE, FALSE, 0 );
+    pCheckBox = new_checkbox_with_title ( _("Do not warn about an already opened file"),
+					  &(etat.display_message_lock_active), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
 
     /* Display a warning message that QIF doesn't contain currencies */
-    bouton_display_lock_active = new_checkbox_with_title ( _("Do not warn about about QIF not containing currencies"),
-							   &(etat.display_message_qif_export_currency), NULL );
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), bouton_display_lock_active, FALSE, FALSE, 0 );
+    pCheckBox = new_checkbox_with_title ( _("Do not warn about QIF not containing currencies"),
+					  &(etat.display_message_qif_export_currency), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
+
+    /* Display a warning message that manually reconciliation isn't a good way */
+    pCheckBox = new_checkbox_with_title ( _("Do not warn about manually reconciliation\n"
+					    "(with shortcut <Ctrl><R>)"),
+					  &(etat.display_message_reconcile_transaction), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
+
+    /* Display a warning message when trying to remove a transaction */
+    pCheckBox = new_checkbox_with_title ( _("Do not warn about removal transaction"),
+					  &(etat.display_message_remove_transaction), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
+
+    /* Display a warning message when trying to remove a scheduled transaction */
+    pCheckBox = new_checkbox_with_title ( _("Do not warn about removal scheduled transaction"),
+					  &(etat.display_message_remove_scheduled_transaction), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
+
+    /* Display a warning message when a breakdown is incomplete */
+    pCheckBox = new_checkbox_with_title ( _("Do not warn about incomplete breakdown"),
+					  &(etat.display_message_incomplete_breakdown), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
+
+    /* Display a warning message when no reconciliation reference given */
+    pCheckBox = new_checkbox_with_title ( _("Do not warn about no reconciliation reference"),
+					  &(etat.display_message_no_reconciliation_ref), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
+
+    /* Display a warning message when no reconciliation reference given */
+    pCheckBox = new_checkbox_with_title ( _("Do not warn about existing reconciliation reference"),
+					  &(etat.display_message_reconciliation_ref_exist), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
+
+    /* Display a warning message when last chance to abort reconciliation */
+    pCheckBox = new_checkbox_with_title ( _("Do not warn about last chance to abort reconciliation"),
+					  &(etat.display_message_aborting_reconciliation), NULL );
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ), pCheckBox, FALSE, FALSE, 0 );
 
 
     /* Number of days before a warning message advertising a scheduled
