@@ -99,6 +99,13 @@ struct {
     guint display_message_file_readable;
     guint display_message_minimum_alert;
     guint display_message_qif_export_currency;
+    guint display_message_reconcile_transaction;
+    guint display_message_remove_transaction;
+    guint display_message_remove_scheduled_transaction;
+    guint display_message_incomplete_breakdown;
+    guint display_message_no_reconciliation_ref;
+    guint display_message_reconciliation_ref_exist;
+    guint display_message_aborting_reconciliation;
 
     /* Various commands */
     gchar * browser_command;
@@ -123,10 +130,10 @@ struct {
 
 /** Etat de rapprochement d'une opération */
 enum operation_etat_rapprochement {
-  OPERATION_NORMALE = 0,
-  OPERATION_POINTEE,
-  OPERATION_RAPPROCHEE,
-  OPERATION_TELERAPPROCHEE,
+  UNCHECKED_TRANSACTION = 0,
+  CHECKED_TRANSACTION,
+  RECONCILED_TRANSACTION,
+  TELECHECKED_TRANSACTION,
 };
 
 
@@ -305,7 +312,7 @@ struct operation_echeance
     gint mois_limite;
     gint annee_limite;
 
-    gint compte_virement;
+    gint compte_virement;     /* à -1 si c'est une échéance sans categ, et que ce n'est ni un virement ni une ventil */
     gint type_contre_ope;        /* variable suivant le compte */
 
     gint operation_ventilee;        /* à 1 si c'est une opé ventilée */
@@ -463,6 +470,7 @@ struct struct_etat
     gint afficher_no_ope;
     gint afficher_type_ope;
     gint afficher_cheque_ope;
+    gint afficher_verif_ope;
     gint afficher_rappr_ope;
     gint afficher_exo_ope;
     gint type_classement_ope;     /* 0=date, 1=no opé, 2=tiers, 3=categ, 4=ib, 5=notes, 6=type ope, 7=no chq, 8=pc, 9=ibg, 10=no rappr */
