@@ -6,7 +6,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
-/*			2003-2004 Alain Portal (dionysos@grisbi.org)	      */
+/*			2003-2004 Alain Portal (aportal@univ-montp2.fr)       */
 /*			2003-2004 Francois Terrot (francois.terrot@grisbi.org)*/
 /* 			http://www.grisbi.org				      */
 /*                                                                            */
@@ -494,11 +494,19 @@ void desensitive_widget ( GtkWidget *widget )
 
 
 
-/* ************************************************************************************************** */
-/* itoa : transforme un integer en chaine ascii */
-/* ************************************************************************************************** */
 
-gchar *itoa ( gint integer )
+/*!
+ * @brief convert an integer into a gchar based string
+ * 
+ * @param integer   integer to convert
+ * 
+ * @return  a newly allocated string
+ * 
+ * @caveats You have to unallocate the returned string when you no more use it to save memory
+ *
+ * @todo: this function is a cause of memory leak
+ */
+gchar *utils_itoa ( gint integer )
 {
     div_t result_div;
     gchar *chaine;
@@ -1803,7 +1811,8 @@ gboolean set_int_from_menu ( GtkWidget * menu, gint * dummy)
 
     if ( data )
     {
-	*data = (gtk_option_menu_get_history ( GTK_OPTION_MENU ( menu )) + 1);
+	*data = GPOINTER_TO_INT (g_object_get_data ( G_OBJECT ( GTK_OPTION_MENU ( menu ) -> menu_item ),
+				    "no_devise" ));
     }
 
     /* Mark file as modified */
