@@ -225,9 +225,6 @@ extern gchar *applet_dir;
 extern gchar *applet_bin_dir;
 
 extern GtkWidget *fenetre_preferences;
-extern GtkWidget *bouton_entree_enregistre, *bouton_entree_enregistre_pas;
-extern GtkWidget *bouton_solde_mini, *bouton_pas_solde_mini;
-extern GtkWidget *bouton_affiche_permission, *bouton_affiche_pas_permission;
 extern GtkWidget *entree_titre_fichier;
 extern GtkWidget *entree_adresse_commune;
 extern GtkWidget *entree_adresse_secondaire;
@@ -594,6 +591,8 @@ extern GtkWidget *liste_type_classement_etat;
 extern GtkWidget *bouton_opes_r_et_non_r_etat;
 extern GtkWidget *bouton_opes_non_r_etat;
 extern GtkWidget *bouton_opes_r_etat;
+extern GtkWidget *bouton_opes_p_etat;
+extern GtkWidget *bouton_opes_ni_p_ni_r_etat;
 extern GtkWidget *bouton_afficher_opes;
 extern GtkWidget *bouton_afficher_nb_opes;
 extern GtkWidget *bouton_afficher_date_opes;
@@ -608,6 +607,7 @@ extern GtkWidget *bouton_afficher_infobd_opes;
 extern GtkWidget *bouton_afficher_no_ope;
 extern GtkWidget *bouton_afficher_type_ope;
 extern GtkWidget *bouton_afficher_no_rappr;
+extern GtkWidget *bouton_afficher_verif;
 extern GtkWidget *bouton_afficher_no_cheque;
 extern GtkWidget *bouton_afficher_exo_opes;
 extern GtkWidget *bouton_pas_detailler_ventilation;
